ord.EE.setup<-function( x, y, id, gvec, cuts, b.model, w.model ){
#
# PURPOSE:	create input for ord.EE()
#
# INPUT:  	x = design matrix (without intercept)
#		y = ordinal measurements
#		id = cluster identifier
#		cuts = category lower boundaries for y
#		gvec = class identifier
#		b.model = model matrix for inter/intra class association
#		w.model = "common" global OR's or "full" global OR's
#		
# RETURN:	returns list with structures needed by ord.alr()
#
	if( !is.loaded(symbol.C("class2z")) ){
		print("ord.alr.setup() calls class2z.")
		print("the object file 'C2Z.o' is not loaded.")
		print("please load this file and try again.")
		stop( 0 ) }
	ncuts<-length(cuts)
	k<-max(gvec)
	nobs_length(y)
	if(min(gvec)!=1){
		print(paste("gvec min is",min(gvec),"."))
		print("expect gvec to range from 1 to max # classes!")
		stop( 0 ) }
	if( !(w.model=="common" || w.model=="full") ){
		print(paste("w.model =",w.model))
		print("choices are either common or full")
		stop( 0 ) }
	y.ord<-ord.build.y( y, cuts )
	id.ord<-ord.build.id( id, ncuts)
	x.ord<-ord.build.x( x, ncuts )
	out1<-class2z( id=id, cvec=gvec, k=k, dmat=b.model)	
	if(w.model=="common"){
		zmat_matrix(1,nrow=ncuts^2,ncol=1) }else{
		zmat_cbind(1,diag(rep(1,ncuts^2))[,-1]) }
	zid.ord_as.vector(kronecker(matrix(out1$zid,ncol=1),zmat))
	z.ord_kronecker(out1$z,zmat)
	ret_list(x=x.ord,y=y.ord,id=id.ord,z=z.ord,zid=zid.ord,ncuts=ncuts,
		b.model=out1$model,w.model=w.model)
	ret
}
ord.build.y<-function( y, cuts ){
	ncuts_length(cuts)
	y.ord_NULL
	for(i in 1:ncuts) y.ord_cbind(y.ord,as.integer(y>cuts[i]))
	y.ord_as.vector(t(y.ord))
	y.ord
}
ord.build.id<-function( id, ncuts ){		
	id.ord_kronecker(matrix(id,ncol=1),matrix(1,nrow=ncuts,ncol=1))
	id.ord_as.vector(id.ord)
	id.ord
}
ord.build.x<-function( x, ncuts ){
	nobs_nrow(x)
	x.ord_kronecker(x,matrix(1,nrow=ncuts,ncol=1))
	x1_matrix(diag(rep(1,ncuts)),ncol=ncuts)
	x1_matrix(kronecker(matrix(1,nobs,1),x1),ncol=ncuts)
	dimnames(x1)_list(NULL,paste("c",c(1:ncuts),sep=""))
	x.ord_cbind(x1,x.ord)
	x.ord
}	


